@@ -11,7 +11,7 @@ use Pod::Usage;
 # use Data::Dumper::Simple;$Data::Dumper::Sortkeys = 1;$Data::Dumper::Purity = 1;
 
 BEGIN {
-    our $VERSION = '2.02';
+    our $VERSION = '2.03';
 }
 
 my $default_dir = '.';
@@ -112,7 +112,7 @@ sub gather {
                 if (defined($r)) {
                     @pics = (@pics, @{$r});
                 }
-            } elsif (-f "$path/$file" && $file =~ /\.(jpg|jpeg|gif|tiff|bmp|png)$/i) {
+            } elsif (-f "$path/$file" && $file =~ /\.(jpg|jpeg|gif|tiff|bmp|png|mkv|mp4|avi|mpeg4|webp)$/i) {
                 push(@pics, "$path/$file");
             }
         } ## end foreach my $file (@dir)
